@@ -163,7 +163,7 @@ use common::sense;
 use Coro;
 use AnyEvent ();
 
-our $VERSION = 6.54;
+our $VERSION = 6.57;
 
 #############################################################################
 # idle handler
@@ -346,19 +346,16 @@ sub writable($;$) {
    Coro::rouse_wait
 }
 
-sub Coro::AnyEvent::CondVar::send {
+sub Coro::AnyEvent::CondVar::_send {
    (delete $_[0]{_ae_coro})->ready if $_[0]{_ae_coro};
-
-   &AnyEvent::CondVar::Base::send;
 };
 
-sub Coro::AnyEvent::CondVar::recv {
+sub Coro::AnyEvent::CondVar::_wait {
    until ($_[0]{_ae_sent}) {
+      $AnyEvent::CondVar::Base::WAITING = 0; # avoid recursive check by AnyEvent
       local $_[0]{_ae_coro} = $Coro::current;
       Coro::schedule;
    }
-
-   &AnyEvent::CondVar::Base::recv;
 };
 
 1;
